@@ -10,7 +10,7 @@ use mit_commit_message_lints::{
 
 use crate::current_dir;
 
-pub(crate) fn run_on_match(matches: &ArgMatches) -> Option<Result<()>> {
+pub fn run_on_match(matches: &ArgMatches) -> Option<Result<()>> {
     matches
         .subcommand_matches("mit")
         .filter(|subcommand| {
@@ -43,7 +43,7 @@ impl Args {
 
 impl From<&ArgMatches> for Args {
     fn from(matches: &ArgMatches) -> Self {
-        Args {
+        Self {
             matches: matches.clone(),
         }
     }
@@ -68,7 +68,7 @@ fn run(matches: &ArgMatches) -> Result<()> {
     let authors = file_authors.merge(&Authors::try_from(&git_config)?);
 
     let output: String = if args.is_generate_command() {
-        to_toml(authors)
+        to_toml(authors)?
     } else {
         author_table(&authors)
     };
@@ -77,6 +77,6 @@ fn run(matches: &ArgMatches) -> Result<()> {
     Ok(())
 }
 
-fn to_toml(authors: Authors) -> String {
-    String::from(authors).trim().to_string()
+fn to_toml(authors: Authors) -> Result<String> {
+    Ok(String::try_from(authors)?.trim().to_string())
 }
